import React from 'react';
import type { FileLike } from '../../ReactFileUtilities';
import type { Attachment, Message, UserResponse } from 'stream-chat';
import type { MessageInputProps } from '../MessageInput';
import type { CustomTrigger, DefaultStreamChatGenerics, SendMessageOptions } from '../../../types/types';
import { EnrichURLsController } from './useLinkPreviews';
import type { FileUpload, ImageUpload, LinkPreviewMap } from '../types';
import { SetLinkPreviewMode } from '../types';
export declare type MessageInputState<StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics> = {
    attachments: Attachment<StreamChatGenerics>[];
    fileOrder: string[];
    fileUploads: Record<string, FileUpload>;
    imageOrder: string[];
    imageUploads: Record<string, ImageUpload>;
    linkPreviews: LinkPreviewMap;
    mentioned_users: UserResponse<StreamChatGenerics>[];
    setText: (text: string) => void;
    text: string;
};
declare type SetTextAction = {
    getNewText: (currentStateText: string) => string;
    type: 'setText';
};
declare type ClearAction = {
    type: 'clear';
};
declare type SetImageUploadAction = {
    id: string;
    type: 'setImageUpload';
    file?: File | FileLike;
    previewUri?: string;
    state?: string;
    url?: string;
};
declare type SetFileUploadAction = {
    id: string;
    type: 'setFileUpload';
    file?: File;
    state?: string;
    thumb_url?: string;
    url?: string;
};
declare type SetLinkPreviewsAction = {
    linkPreviews: LinkPreviewMap;
    mode: SetLinkPreviewMode;
    type: 'setLinkPreviews';
};
declare type RemoveImageUploadAction = {
    id: string;
    type: 'removeImageUpload';
};
declare type RemoveFileUploadAction = {
    id: string;
    type: 'removeFileUpload';
};
declare type AddMentionedUserAction<StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics> = {
    type: 'addMentionedUser';
    user: UserResponse<StreamChatGenerics>;
};
export declare type MessageInputReducerAction<StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics> = SetTextAction | ClearAction | SetImageUploadAction | SetFileUploadAction | SetLinkPreviewsAction | RemoveImageUploadAction | RemoveFileUploadAction | AddMentionedUserAction<StreamChatGenerics>;
export declare type MessageInputHookProps<StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics> = EnrichURLsController & {
    handleChange: React.ChangeEventHandler<HTMLTextAreaElement>;
    handleSubmit: (event: React.BaseSyntheticEvent, customMessageData?: Partial<Message<StreamChatGenerics>>, options?: SendMessageOptions) => void;
    insertText: (textToInsert: string) => void;
    isUploadEnabled: boolean;
    maxFilesLeft: number;
    numberOfUploads: number;
    onPaste: (event: React.ClipboardEvent<HTMLTextAreaElement>) => void;
    onSelectUser: (item: UserResponse<StreamChatGenerics>) => void;
    removeFile: (id: string) => void;
    removeImage: (id: string) => void;
    textareaRef: React.MutableRefObject<HTMLTextAreaElement | null | undefined>;
    uploadFile: (id: string) => void;
    uploadImage: (id: string) => void;
    uploadNewFiles: (files: FileList | File[]) => void;
};
export declare type CommandsListState = {
    closeCommandsList: () => void;
    openCommandsList: () => void;
    showCommandsList: boolean;
};
export declare type MentionsListState = {
    closeMentionsList: () => void;
    openMentionsList: () => void;
    showMentionsList: boolean;
};
/**
 * hook for MessageInput state
 */
export declare const useMessageInputState: <StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics, V extends CustomTrigger = CustomTrigger>(props: MessageInputProps<StreamChatGenerics, V>) => MessageInputState<StreamChatGenerics> & EnrichURLsController & {
    handleChange: React.ChangeEventHandler<HTMLTextAreaElement>;
    handleSubmit: (event: React.BaseSyntheticEvent, customMessageData?: Partial<Message<StreamChatGenerics>> | undefined, options?: SendMessageOptions) => void;
    insertText: (textToInsert: string) => void;
    isUploadEnabled: boolean;
    maxFilesLeft: number;
    numberOfUploads: number;
    onPaste: (event: React.ClipboardEvent<HTMLTextAreaElement>) => void;
    onSelectUser: (item: UserResponse<StreamChatGenerics>) => void;
    removeFile: (id: string) => void;
    removeImage: (id: string) => void;
    textareaRef: React.MutableRefObject<HTMLTextAreaElement | null | undefined>;
    uploadFile: (id: string) => void;
    uploadImage: (id: string) => void;
    uploadNewFiles: (files: FileList | File[]) => void;
} & CommandsListState & MentionsListState;
export {};
//# sourceMappingURL=useMessageInputState.d.ts.map