import React, { Dispatch, PropsWithChildren, SetStateAction } from 'react';
import type { AppSettingsAPIResponse, Channel, Mute } from 'stream-chat';
import type { ChatProps } from '../components/Chat/Chat';
import type { DefaultStreamChatGenerics, UnknownType } from '../types/types';
import type { ChannelsQueryState } from '../components/Chat/hooks/useChannelsQueryState';
declare type CSSClasses = 'chat' | 'chatContainer' | 'channel' | 'channelList' | 'message' | 'messageList' | 'thread' | 'threadList' | 'virtualMessage' | 'virtualizedMessageList';
export declare type CustomClasses = Partial<Record<CSSClasses, string>>;
declare type ChannelCID = string;
export declare type ThemeVersion = '1' | '2';
export declare type ChatContextValue<StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics> = {
    /**
     * State representing the array of loaded channels.
     * Channels query is executed by default only by ChannelList component in the SDK.
     */
    channels: Channel<StreamChatGenerics>[];
    /**
     * Indicates, whether a channels query has been triggered within ChannelList by its channels pagination controller.
     */
    channelsQueryState: ChannelsQueryState;
    closeMobileNav: () => void;
    getAppSettings: () => Promise<AppSettingsAPIResponse<StreamChatGenerics>> | null;
    latestMessageDatesByChannels: Record<ChannelCID, Date>;
    mutes: Array<Mute<StreamChatGenerics>>;
    openMobileNav: () => void;
    /**
     * Sets active channel to be rendered within Channel component.
     * @param newChannel
     * @param watchers
     * @param event
     */
    setActiveChannel: (newChannel?: Channel<StreamChatGenerics>, watchers?: {
        limit?: number;
        offset?: number;
    }, event?: React.BaseSyntheticEvent) => void;
    /**
     * Sets the list of Channel objects to be rendered by ChannelList component.
     */
    setChannels: Dispatch<SetStateAction<Channel<StreamChatGenerics>[]>>;
    /**
     * Allows to opt out of the use of legacy CSS (version "1") and opt into the use of the latest SDK's CSS (version "2").
     */
    themeVersion: ThemeVersion;
    useImageFlagEmojisOnWindows: boolean;
    /**
     * Active channel used to render the contents of the Channel component.
     */
    channel?: Channel<StreamChatGenerics>;
    /**
     * Object through which custom classes can be set for main container components of the SDK.
     */
    customClasses?: CustomClasses;
    navOpen?: boolean;
} & Required<Pick<ChatProps<StreamChatGenerics>, 'theme' | 'client'>>;
export declare const ChatContext: React.Context<ChatContextValue<DefaultStreamChatGenerics> | undefined>;
export declare const ChatProvider: <StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics>({ children, value, }: React.PropsWithChildren<{
    value: ChatContextValue<StreamChatGenerics>;
}>) => JSX.Element;
export declare const useChatContext: <StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics>(componentName?: string) => ChatContextValue<StreamChatGenerics>;
/**
 * Typescript currently does not support partial inference so if ChatContext
 * typing is desired while using the HOC withChatContext the Props for the
 * wrapped component must be provided as the first generic.
 */
export declare const withChatContext: <P extends UnknownType, StreamChatGenerics extends DefaultStreamChatGenerics = DefaultStreamChatGenerics>(Component: React.ComponentType<P>) => {
    (props: Omit<P, "client" | "channel" | "mutes" | "channels" | "setChannels" | "navOpen" | "latestMessageDatesByChannels" | "theme" | "channelsQueryState" | "closeMobileNav" | "customClasses" | "getAppSettings" | "openMobileNav" | "setActiveChannel" | "themeVersion" | "useImageFlagEmojisOnWindows">): JSX.Element;
    displayName: string;
};
export {};
//# sourceMappingURL=ChatContext.d.ts.map